/**
 * Copyright (c) 2000-2010 Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package nl.jteam.demo.service;

import com.liferay.portal.kernel.annotation.Isolation;
import com.liferay.portal.kernel.annotation.Propagation;
import com.liferay.portal.kernel.annotation.Transactional;
import com.liferay.portal.kernel.exception.PortalException;
import com.liferay.portal.kernel.exception.SystemException;

/**
 * The interface for the cal event invitation local service.
 *
 * <p>
 * Never modify or reference this interface directly. Always use {@link CalEventInvitationLocalServiceUtil} to access the cal event invitation local service. Add custom service methods to {@link nl.jteam.demo.service.impl.CalEventInvitationLocalServiceImpl} and rerun ServiceBuilder to automatically copy the method declarations to this interface.
 * </p>
 *
 * <p>
 * This is a local service. Methods of this service will not have security checks based on the propagated JAAS credentials because this service can only be accessed from within the same VM.
 * </p>
 *
 * @author Brian Wing Shun Chan
 * @see CalEventInvitationLocalServiceUtil
 * @see nl.jteam.demo.service.base.CalEventInvitationLocalServiceBaseImpl
 * @see nl.jteam.demo.service.impl.CalEventInvitationLocalServiceImpl
 * @generated
 */
@Transactional(isolation = Isolation.PORTAL, rollbackFor =  {
	PortalException.class, SystemException.class})
public interface CalEventInvitationLocalService {
	/**
	* Adds the cal event invitation to the database. Also notifies the appropriate model listeners.
	*
	* @param calEventInvitation the cal event invitation to add
	* @return the cal event invitation that was added
	* @throws SystemException if a system exception occurred
	*/
	public nl.jteam.demo.model.CalEventInvitation addCalEventInvitation(
		nl.jteam.demo.model.CalEventInvitation calEventInvitation)
		throws com.liferay.portal.kernel.exception.SystemException;

	/**
	* Creates a new cal event invitation with the primary key. Does not add the cal event invitation to the database.
	*
	* @param CalEventInvitationId the primary key for the new cal event invitation
	* @return the new cal event invitation
	*/
	public nl.jteam.demo.model.CalEventInvitation createCalEventInvitation(
		long CalEventInvitationId);

	/**
	* Deletes the cal event invitation with the primary key from the database. Also notifies the appropriate model listeners.
	*
	* @param CalEventInvitationId the primary key of the cal event invitation to delete
	* @throws PortalException if a cal event invitation with the primary key could not be found
	* @throws SystemException if a system exception occurred
	*/
	public void deleteCalEventInvitation(long CalEventInvitationId)
		throws com.liferay.portal.kernel.exception.PortalException,
			com.liferay.portal.kernel.exception.SystemException;

	/**
	* Deletes the cal event invitation from the database. Also notifies the appropriate model listeners.
	*
	* @param calEventInvitation the cal event invitation to delete
	* @throws SystemException if a system exception occurred
	*/
	public void deleteCalEventInvitation(
		nl.jteam.demo.model.CalEventInvitation calEventInvitation)
		throws com.liferay.portal.kernel.exception.SystemException;

	/**
	* Performs a dynamic query on the database and returns the matching rows.
	*
	* @param dynamicQuery the dynamic query to search with
	* @return the matching rows
	* @throws SystemException if a system exception occurred
	*/
	@SuppressWarnings("rawtypes")
	public java.util.List dynamicQuery(
		com.liferay.portal.kernel.dao.orm.DynamicQuery dynamicQuery)
		throws com.liferay.portal.kernel.exception.SystemException;

	/**
	* Performs a dynamic query on the database and returns a range of the matching rows.
	*
	* <p>
	* Useful when paginating results. Returns a maximum of <code>end - start</code> instances. <code>start</code> and <code>end</code> are not primary keys, they are indexes in the result set. Thus, <code>0</code> refers to the first result in the set. Setting both <code>start</code> and <code>end</code> to {@link com.liferay.portal.kernel.dao.orm.QueryUtil#ALL_POS} will return the full result set.
	* </p>
	*
	* @param dynamicQuery the dynamic query to search with
	* @param start the lower bound of the range of model instances to return
	* @param end the upper bound of the range of model instances to return (not inclusive)
	* @return the range of matching rows
	* @throws SystemException if a system exception occurred
	*/
	@SuppressWarnings("rawtypes")
	public java.util.List dynamicQuery(
		com.liferay.portal.kernel.dao.orm.DynamicQuery dynamicQuery, int start,
		int end) throws com.liferay.portal.kernel.exception.SystemException;

	/**
	* Performs a dynamic query on the database and returns an ordered range of the matching rows.
	*
	* <p>
	* Useful when paginating results. Returns a maximum of <code>end - start</code> instances. <code>start</code> and <code>end</code> are not primary keys, they are indexes in the result set. Thus, <code>0</code> refers to the first result in the set. Setting both <code>start</code> and <code>end</code> to {@link com.liferay.portal.kernel.dao.orm.QueryUtil#ALL_POS} will return the full result set.
	* </p>
	*
	* @param dynamicQuery the dynamic query to search with
	* @param start the lower bound of the range of model instances to return
	* @param end the upper bound of the range of model instances to return (not inclusive)
	* @param orderByComparator the comparator to order the results by
	* @return the ordered range of matching rows
	* @throws SystemException if a system exception occurred
	*/
	@SuppressWarnings("rawtypes")
	public java.util.List dynamicQuery(
		com.liferay.portal.kernel.dao.orm.DynamicQuery dynamicQuery, int start,
		int end,
		com.liferay.portal.kernel.util.OrderByComparator orderByComparator)
		throws com.liferay.portal.kernel.exception.SystemException;

	/**
	* Counts the number of rows that match the dynamic query.
	*
	* @param dynamicQuery the dynamic query to search with
	* @return the number of rows that match the dynamic query
	* @throws SystemException if a system exception occurred
	*/
	public long dynamicQueryCount(
		com.liferay.portal.kernel.dao.orm.DynamicQuery dynamicQuery)
		throws com.liferay.portal.kernel.exception.SystemException;

	/**
	* Gets the cal event invitation with the primary key.
	*
	* @param CalEventInvitationId the primary key of the cal event invitation to get
	* @return the cal event invitation
	* @throws PortalException if a cal event invitation with the primary key could not be found
	* @throws SystemException if a system exception occurred
	*/
	@Transactional(propagation = Propagation.SUPPORTS, readOnly = true)
	public nl.jteam.demo.model.CalEventInvitation getCalEventInvitation(
		long CalEventInvitationId)
		throws com.liferay.portal.kernel.exception.PortalException,
			com.liferay.portal.kernel.exception.SystemException;

	/**
	* Gets a range of all the cal event invitations.
	*
	* <p>
	* Useful when paginating results. Returns a maximum of <code>end - start</code> instances. <code>start</code> and <code>end</code> are not primary keys, they are indexes in the result set. Thus, <code>0</code> refers to the first result in the set. Setting both <code>start</code> and <code>end</code> to {@link com.liferay.portal.kernel.dao.orm.QueryUtil#ALL_POS} will return the full result set.
	* </p>
	*
	* @param start the lower bound of the range of cal event invitations to return
	* @param end the upper bound of the range of cal event invitations to return (not inclusive)
	* @return the range of cal event invitations
	* @throws SystemException if a system exception occurred
	*/
	@Transactional(propagation = Propagation.SUPPORTS, readOnly = true)
	public java.util.List<nl.jteam.demo.model.CalEventInvitation> getCalEventInvitations(
		int start, int end)
		throws com.liferay.portal.kernel.exception.SystemException;

	/**
	* Gets the number of cal event invitations.
	*
	* @return the number of cal event invitations
	* @throws SystemException if a system exception occurred
	*/
	@Transactional(propagation = Propagation.SUPPORTS, readOnly = true)
	public int getCalEventInvitationsCount()
		throws com.liferay.portal.kernel.exception.SystemException;

	/**
	* Updates the cal event invitation in the database. Also notifies the appropriate model listeners.
	*
	* @param calEventInvitation the cal event invitation to update
	* @return the cal event invitation that was updated
	* @throws SystemException if a system exception occurred
	*/
	public nl.jteam.demo.model.CalEventInvitation updateCalEventInvitation(
		nl.jteam.demo.model.CalEventInvitation calEventInvitation)
		throws com.liferay.portal.kernel.exception.SystemException;

	/**
	* Updates the cal event invitation in the database. Also notifies the appropriate model listeners.
	*
	* @param calEventInvitation the cal event invitation to update
	* @param merge whether to merge the cal event invitation with the current session. See {@link com.liferay.portal.service.persistence.BatchSession#update(com.liferay.portal.kernel.dao.orm.Session, com.liferay.portal.model.BaseModel, boolean)} for an explanation.
	* @return the cal event invitation that was updated
	* @throws SystemException if a system exception occurred
	*/
	public nl.jteam.demo.model.CalEventInvitation updateCalEventInvitation(
		nl.jteam.demo.model.CalEventInvitation calEventInvitation, boolean merge)
		throws com.liferay.portal.kernel.exception.SystemException;

	public nl.jteam.demo.model.CalEventInvitation createCalEventInvitation()
		throws com.liferay.portal.kernel.exception.SystemException;

	public nl.jteam.demo.model.CalEventInvitation fetchByCalEventCopyId(
		long calEventCopyId)
		throws com.liferay.portal.kernel.exception.SystemException,
			nl.jteam.demo.NoSuchCalEventInvitationException;
}