/**
 * Copyright (c) 2000-2010 Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package nl.jteam.demo.service.persistence;

import com.liferay.portal.service.persistence.BasePersistence;

import nl.jteam.demo.model.CalEventInvitation;

/**
 * The persistence interface for the cal event invitation service.
 *
 * <p>
 * Never modify or reference this interface directly. Always use {@link CalEventInvitationUtil} to access the cal event invitation persistence. Modify <code>service.xml</code> and rerun ServiceBuilder to regenerate this interface.
 * </p>
 *
 * <p>
 * Caching information and settings can be found in <code>portal.properties</code>
 * </p>
 *
 * @author Brian Wing Shun Chan
 * @see CalEventInvitationPersistenceImpl
 * @see CalEventInvitationUtil
 * @generated
 */
public interface CalEventInvitationPersistence extends BasePersistence<CalEventInvitation> {
	/**
	* Caches the cal event invitation in the entity cache if it is enabled.
	*
	* @param calEventInvitation the cal event invitation to cache
	*/
	public void cacheResult(
		nl.jteam.demo.model.CalEventInvitation calEventInvitation);

	/**
	* Caches the cal event invitations in the entity cache if it is enabled.
	*
	* @param calEventInvitations the cal event invitations to cache
	*/
	public void cacheResult(
		java.util.List<nl.jteam.demo.model.CalEventInvitation> calEventInvitations);

	/**
	* Creates a new cal event invitation with the primary key. Does not add the cal event invitation to the database.
	*
	* @param CalEventInvitationId the primary key for the new cal event invitation
	* @return the new cal event invitation
	*/
	public nl.jteam.demo.model.CalEventInvitation create(
		long CalEventInvitationId);

	/**
	* Removes the cal event invitation with the primary key from the database. Also notifies the appropriate model listeners.
	*
	* @param CalEventInvitationId the primary key of the cal event invitation to remove
	* @return the cal event invitation that was removed
	* @throws nl.jteam.demo.NoSuchCalEventInvitationException if a cal event invitation with the primary key could not be found
	* @throws SystemException if a system exception occurred
	*/
	public nl.jteam.demo.model.CalEventInvitation remove(
		long CalEventInvitationId)
		throws com.liferay.portal.kernel.exception.SystemException,
			nl.jteam.demo.NoSuchCalEventInvitationException;

	public nl.jteam.demo.model.CalEventInvitation updateImpl(
		nl.jteam.demo.model.CalEventInvitation calEventInvitation, boolean merge)
		throws com.liferay.portal.kernel.exception.SystemException;

	/**
	* Finds the cal event invitation with the primary key or throws a {@link nl.jteam.demo.NoSuchCalEventInvitationException} if it could not be found.
	*
	* @param CalEventInvitationId the primary key of the cal event invitation to find
	* @return the cal event invitation
	* @throws nl.jteam.demo.NoSuchCalEventInvitationException if a cal event invitation with the primary key could not be found
	* @throws SystemException if a system exception occurred
	*/
	public nl.jteam.demo.model.CalEventInvitation findByPrimaryKey(
		long CalEventInvitationId)
		throws com.liferay.portal.kernel.exception.SystemException,
			nl.jteam.demo.NoSuchCalEventInvitationException;

	/**
	* Finds the cal event invitation with the primary key or returns <code>null</code> if it could not be found.
	*
	* @param CalEventInvitationId the primary key of the cal event invitation to find
	* @return the cal event invitation, or <code>null</code> if a cal event invitation with the primary key could not be found
	* @throws SystemException if a system exception occurred
	*/
	public nl.jteam.demo.model.CalEventInvitation fetchByPrimaryKey(
		long CalEventInvitationId)
		throws com.liferay.portal.kernel.exception.SystemException;

	/**
	* Finds the cal event invitation where calEventCopyId = &#63; or throws a {@link nl.jteam.demo.NoSuchCalEventInvitationException} if it could not be found.
	*
	* @param calEventCopyId the cal event copy id to search with
	* @return the matching cal event invitation
	* @throws nl.jteam.demo.NoSuchCalEventInvitationException if a matching cal event invitation could not be found
	* @throws SystemException if a system exception occurred
	*/
	public nl.jteam.demo.model.CalEventInvitation findByCalEventCopyId(
		long calEventCopyId)
		throws com.liferay.portal.kernel.exception.SystemException,
			nl.jteam.demo.NoSuchCalEventInvitationException;

	/**
	* Finds the cal event invitation where calEventCopyId = &#63; or returns <code>null</code> if it could not be found. Uses the finder cache.
	*
	* @param calEventCopyId the cal event copy id to search with
	* @return the matching cal event invitation, or <code>null</code> if a matching cal event invitation could not be found
	* @throws SystemException if a system exception occurred
	*/
	public nl.jteam.demo.model.CalEventInvitation fetchByCalEventCopyId(
		long calEventCopyId)
		throws com.liferay.portal.kernel.exception.SystemException;

	/**
	* Finds the cal event invitation where calEventCopyId = &#63; or returns <code>null</code> if it could not be found, optionally using the finder cache.
	*
	* @param calEventCopyId the cal event copy id to search with
	* @return the matching cal event invitation, or <code>null</code> if a matching cal event invitation could not be found
	* @throws SystemException if a system exception occurred
	*/
	public nl.jteam.demo.model.CalEventInvitation fetchByCalEventCopyId(
		long calEventCopyId, boolean retrieveFromCache)
		throws com.liferay.portal.kernel.exception.SystemException;

	/**
	* Finds all the cal event invitations.
	*
	* @return the cal event invitations
	* @throws SystemException if a system exception occurred
	*/
	public java.util.List<nl.jteam.demo.model.CalEventInvitation> findAll()
		throws com.liferay.portal.kernel.exception.SystemException;

	/**
	* Finds a range of all the cal event invitations.
	*
	* <p>
	* Useful when paginating results. Returns a maximum of <code>end - start</code> instances. <code>start</code> and <code>end</code> are not primary keys, they are indexes in the result set. Thus, <code>0</code> refers to the first result in the set. Setting both <code>start</code> and <code>end</code> to {@link com.liferay.portal.kernel.dao.orm.QueryUtil#ALL_POS} will return the full result set.
	* </p>
	*
	* @param start the lower bound of the range of cal event invitations to return
	* @param end the upper bound of the range of cal event invitations to return (not inclusive)
	* @return the range of cal event invitations
	* @throws SystemException if a system exception occurred
	*/
	public java.util.List<nl.jteam.demo.model.CalEventInvitation> findAll(
		int start, int end)
		throws com.liferay.portal.kernel.exception.SystemException;

	/**
	* Finds an ordered range of all the cal event invitations.
	*
	* <p>
	* Useful when paginating results. Returns a maximum of <code>end - start</code> instances. <code>start</code> and <code>end</code> are not primary keys, they are indexes in the result set. Thus, <code>0</code> refers to the first result in the set. Setting both <code>start</code> and <code>end</code> to {@link com.liferay.portal.kernel.dao.orm.QueryUtil#ALL_POS} will return the full result set.
	* </p>
	*
	* @param start the lower bound of the range of cal event invitations to return
	* @param end the upper bound of the range of cal event invitations to return (not inclusive)
	* @param orderByComparator the comparator to order the results by
	* @return the ordered range of cal event invitations
	* @throws SystemException if a system exception occurred
	*/
	public java.util.List<nl.jteam.demo.model.CalEventInvitation> findAll(
		int start, int end,
		com.liferay.portal.kernel.util.OrderByComparator orderByComparator)
		throws com.liferay.portal.kernel.exception.SystemException;

	/**
	* Removes the cal event invitation where calEventCopyId = &#63; from the database.
	*
	* @param calEventCopyId the cal event copy id to search with
	* @throws SystemException if a system exception occurred
	*/
	public void removeByCalEventCopyId(long calEventCopyId)
		throws com.liferay.portal.kernel.exception.SystemException,
			nl.jteam.demo.NoSuchCalEventInvitationException;

	/**
	* Removes all the cal event invitations from the database.
	*
	* @throws SystemException if a system exception occurred
	*/
	public void removeAll()
		throws com.liferay.portal.kernel.exception.SystemException;

	/**
	* Counts all the cal event invitations where calEventCopyId = &#63;.
	*
	* @param calEventCopyId the cal event copy id to search with
	* @return the number of matching cal event invitations
	* @throws SystemException if a system exception occurred
	*/
	public int countByCalEventCopyId(long calEventCopyId)
		throws com.liferay.portal.kernel.exception.SystemException;

	/**
	* Counts all the cal event invitations.
	*
	* @return the number of cal event invitations
	* @throws SystemException if a system exception occurred
	*/
	public int countAll()
		throws com.liferay.portal.kernel.exception.SystemException;
}