/**
 * Copyright (c) 2000-2010 Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package nl.jteam.demo.service.base;

import com.liferay.counter.service.CounterLocalService;

import com.liferay.portal.kernel.annotation.BeanReference;
import com.liferay.portal.kernel.dao.jdbc.SqlUpdate;
import com.liferay.portal.kernel.dao.jdbc.SqlUpdateFactoryUtil;
import com.liferay.portal.kernel.dao.orm.DynamicQuery;
import com.liferay.portal.kernel.exception.PortalException;
import com.liferay.portal.kernel.exception.SystemException;
import com.liferay.portal.kernel.util.OrderByComparator;
import com.liferay.portal.service.ResourceLocalService;
import com.liferay.portal.service.ResourceService;
import com.liferay.portal.service.UserLocalService;
import com.liferay.portal.service.UserService;
import com.liferay.portal.service.persistence.ResourcePersistence;
import com.liferay.portal.service.persistence.UserPersistence;

import nl.jteam.demo.model.CalEventInvitation;
import nl.jteam.demo.service.CalEventInvitationLocalService;
import nl.jteam.demo.service.CalEventInvitationService;
import nl.jteam.demo.service.persistence.CalEventInvitationPersistence;

import java.util.List;

import javax.sql.DataSource;

/**
 * The base implementation of the cal event invitation local service.
 *
 * <p>
 * This implementation exists only as a container for the default service methods generated by ServiceBuilder. All custom service methods should be put in {@link nl.jteam.demo.service.impl.CalEventInvitationLocalServiceImpl}.
 * </p>
 *
 * <p>
 * Never modify or reference this class directly. Always use {@link nl.jteam.demo.service.CalEventInvitationLocalServiceUtil} to access the cal event invitation local service.
 * </p>
 *
 * @author Brian Wing Shun Chan
 * @see nl.jteam.demo.service.impl.CalEventInvitationLocalServiceImpl
 * @see nl.jteam.demo.service.CalEventInvitationLocalServiceUtil
 * @generated
 */
public abstract class CalEventInvitationLocalServiceBaseImpl
	implements CalEventInvitationLocalService {
	/**
	 * Adds the cal event invitation to the database. Also notifies the appropriate model listeners.
	 *
	 * @param calEventInvitation the cal event invitation to add
	 * @return the cal event invitation that was added
	 * @throws SystemException if a system exception occurred
	 */
	public CalEventInvitation addCalEventInvitation(
		CalEventInvitation calEventInvitation) throws SystemException {
		calEventInvitation.setNew(true);

		return calEventInvitationPersistence.update(calEventInvitation, false);
	}

	/**
	 * Creates a new cal event invitation with the primary key. Does not add the cal event invitation to the database.
	 *
	 * @param CalEventInvitationId the primary key for the new cal event invitation
	 * @return the new cal event invitation
	 */
	public CalEventInvitation createCalEventInvitation(
		long CalEventInvitationId) {
		return calEventInvitationPersistence.create(CalEventInvitationId);
	}

	/**
	 * Deletes the cal event invitation with the primary key from the database. Also notifies the appropriate model listeners.
	 *
	 * @param CalEventInvitationId the primary key of the cal event invitation to delete
	 * @throws PortalException if a cal event invitation with the primary key could not be found
	 * @throws SystemException if a system exception occurred
	 */
	public void deleteCalEventInvitation(long CalEventInvitationId)
		throws PortalException, SystemException {
		calEventInvitationPersistence.remove(CalEventInvitationId);
	}

	/**
	 * Deletes the cal event invitation from the database. Also notifies the appropriate model listeners.
	 *
	 * @param calEventInvitation the cal event invitation to delete
	 * @throws SystemException if a system exception occurred
	 */
	public void deleteCalEventInvitation(CalEventInvitation calEventInvitation)
		throws SystemException {
		calEventInvitationPersistence.remove(calEventInvitation);
	}

	/**
	 * Performs a dynamic query on the database and returns the matching rows.
	 *
	 * @param dynamicQuery the dynamic query to search with
	 * @return the matching rows
	 * @throws SystemException if a system exception occurred
	 */
	@SuppressWarnings("rawtypes")
	public List dynamicQuery(DynamicQuery dynamicQuery)
		throws SystemException {
		return calEventInvitationPersistence.findWithDynamicQuery(dynamicQuery);
	}

	/**
	 * Performs a dynamic query on the database and returns a range of the matching rows.
	 *
	 * <p>
	 * Useful when paginating results. Returns a maximum of <code>end - start</code> instances. <code>start</code> and <code>end</code> are not primary keys, they are indexes in the result set. Thus, <code>0</code> refers to the first result in the set. Setting both <code>start</code> and <code>end</code> to {@link com.liferay.portal.kernel.dao.orm.QueryUtil#ALL_POS} will return the full result set.
	 * </p>
	 *
	 * @param dynamicQuery the dynamic query to search with
	 * @param start the lower bound of the range of model instances to return
	 * @param end the upper bound of the range of model instances to return (not inclusive)
	 * @return the range of matching rows
	 * @throws SystemException if a system exception occurred
	 */
	@SuppressWarnings("rawtypes")
	public List dynamicQuery(DynamicQuery dynamicQuery, int start, int end)
		throws SystemException {
		return calEventInvitationPersistence.findWithDynamicQuery(dynamicQuery,
			start, end);
	}

	/**
	 * Performs a dynamic query on the database and returns an ordered range of the matching rows.
	 *
	 * <p>
	 * Useful when paginating results. Returns a maximum of <code>end - start</code> instances. <code>start</code> and <code>end</code> are not primary keys, they are indexes in the result set. Thus, <code>0</code> refers to the first result in the set. Setting both <code>start</code> and <code>end</code> to {@link com.liferay.portal.kernel.dao.orm.QueryUtil#ALL_POS} will return the full result set.
	 * </p>
	 *
	 * @param dynamicQuery the dynamic query to search with
	 * @param start the lower bound of the range of model instances to return
	 * @param end the upper bound of the range of model instances to return (not inclusive)
	 * @param orderByComparator the comparator to order the results by
	 * @return the ordered range of matching rows
	 * @throws SystemException if a system exception occurred
	 */
	@SuppressWarnings("rawtypes")
	public List dynamicQuery(DynamicQuery dynamicQuery, int start, int end,
		OrderByComparator orderByComparator) throws SystemException {
		return calEventInvitationPersistence.findWithDynamicQuery(dynamicQuery,
			start, end, orderByComparator);
	}

	/**
	 * Counts the number of rows that match the dynamic query.
	 *
	 * @param dynamicQuery the dynamic query to search with
	 * @return the number of rows that match the dynamic query
	 * @throws SystemException if a system exception occurred
	 */
	public long dynamicQueryCount(DynamicQuery dynamicQuery)
		throws SystemException {
		return calEventInvitationPersistence.countWithDynamicQuery(dynamicQuery);
	}

	/**
	 * Gets the cal event invitation with the primary key.
	 *
	 * @param CalEventInvitationId the primary key of the cal event invitation to get
	 * @return the cal event invitation
	 * @throws PortalException if a cal event invitation with the primary key could not be found
	 * @throws SystemException if a system exception occurred
	 */
	public CalEventInvitation getCalEventInvitation(long CalEventInvitationId)
		throws PortalException, SystemException {
		return calEventInvitationPersistence.findByPrimaryKey(CalEventInvitationId);
	}

	/**
	 * Gets a range of all the cal event invitations.
	 *
	 * <p>
	 * Useful when paginating results. Returns a maximum of <code>end - start</code> instances. <code>start</code> and <code>end</code> are not primary keys, they are indexes in the result set. Thus, <code>0</code> refers to the first result in the set. Setting both <code>start</code> and <code>end</code> to {@link com.liferay.portal.kernel.dao.orm.QueryUtil#ALL_POS} will return the full result set.
	 * </p>
	 *
	 * @param start the lower bound of the range of cal event invitations to return
	 * @param end the upper bound of the range of cal event invitations to return (not inclusive)
	 * @return the range of cal event invitations
	 * @throws SystemException if a system exception occurred
	 */
	public List<CalEventInvitation> getCalEventInvitations(int start, int end)
		throws SystemException {
		return calEventInvitationPersistence.findAll(start, end);
	}

	/**
	 * Gets the number of cal event invitations.
	 *
	 * @return the number of cal event invitations
	 * @throws SystemException if a system exception occurred
	 */
	public int getCalEventInvitationsCount() throws SystemException {
		return calEventInvitationPersistence.countAll();
	}

	/**
	 * Updates the cal event invitation in the database. Also notifies the appropriate model listeners.
	 *
	 * @param calEventInvitation the cal event invitation to update
	 * @return the cal event invitation that was updated
	 * @throws SystemException if a system exception occurred
	 */
	public CalEventInvitation updateCalEventInvitation(
		CalEventInvitation calEventInvitation) throws SystemException {
		calEventInvitation.setNew(false);

		return calEventInvitationPersistence.update(calEventInvitation, true);
	}

	/**
	 * Updates the cal event invitation in the database. Also notifies the appropriate model listeners.
	 *
	 * @param calEventInvitation the cal event invitation to update
	 * @param merge whether to merge the cal event invitation with the current session. See {@link com.liferay.portal.service.persistence.BatchSession#update(com.liferay.portal.kernel.dao.orm.Session, com.liferay.portal.model.BaseModel, boolean)} for an explanation.
	 * @return the cal event invitation that was updated
	 * @throws SystemException if a system exception occurred
	 */
	public CalEventInvitation updateCalEventInvitation(
		CalEventInvitation calEventInvitation, boolean merge)
		throws SystemException {
		calEventInvitation.setNew(false);

		return calEventInvitationPersistence.update(calEventInvitation, merge);
	}

	/**
	 * Gets the cal event invitation local service.
	 *
	 * @return the cal event invitation local service
	 */
	public CalEventInvitationLocalService getCalEventInvitationLocalService() {
		return calEventInvitationLocalService;
	}

	/**
	 * Sets the cal event invitation local service.
	 *
	 * @param calEventInvitationLocalService the cal event invitation local service
	 */
	public void setCalEventInvitationLocalService(
		CalEventInvitationLocalService calEventInvitationLocalService) {
		this.calEventInvitationLocalService = calEventInvitationLocalService;
	}

	/**
	 * Gets the cal event invitation remote service.
	 *
	 * @return the cal event invitation remote service
	 */
	public CalEventInvitationService getCalEventInvitationService() {
		return calEventInvitationService;
	}

	/**
	 * Sets the cal event invitation remote service.
	 *
	 * @param calEventInvitationService the cal event invitation remote service
	 */
	public void setCalEventInvitationService(
		CalEventInvitationService calEventInvitationService) {
		this.calEventInvitationService = calEventInvitationService;
	}

	/**
	 * Gets the cal event invitation persistence.
	 *
	 * @return the cal event invitation persistence
	 */
	public CalEventInvitationPersistence getCalEventInvitationPersistence() {
		return calEventInvitationPersistence;
	}

	/**
	 * Sets the cal event invitation persistence.
	 *
	 * @param calEventInvitationPersistence the cal event invitation persistence
	 */
	public void setCalEventInvitationPersistence(
		CalEventInvitationPersistence calEventInvitationPersistence) {
		this.calEventInvitationPersistence = calEventInvitationPersistence;
	}

	/**
	 * Gets the counter local service.
	 *
	 * @return the counter local service
	 */
	public CounterLocalService getCounterLocalService() {
		return counterLocalService;
	}

	/**
	 * Sets the counter local service.
	 *
	 * @param counterLocalService the counter local service
	 */
	public void setCounterLocalService(CounterLocalService counterLocalService) {
		this.counterLocalService = counterLocalService;
	}

	/**
	 * Gets the resource local service.
	 *
	 * @return the resource local service
	 */
	public ResourceLocalService getResourceLocalService() {
		return resourceLocalService;
	}

	/**
	 * Sets the resource local service.
	 *
	 * @param resourceLocalService the resource local service
	 */
	public void setResourceLocalService(
		ResourceLocalService resourceLocalService) {
		this.resourceLocalService = resourceLocalService;
	}

	/**
	 * Gets the resource remote service.
	 *
	 * @return the resource remote service
	 */
	public ResourceService getResourceService() {
		return resourceService;
	}

	/**
	 * Sets the resource remote service.
	 *
	 * @param resourceService the resource remote service
	 */
	public void setResourceService(ResourceService resourceService) {
		this.resourceService = resourceService;
	}

	/**
	 * Gets the resource persistence.
	 *
	 * @return the resource persistence
	 */
	public ResourcePersistence getResourcePersistence() {
		return resourcePersistence;
	}

	/**
	 * Sets the resource persistence.
	 *
	 * @param resourcePersistence the resource persistence
	 */
	public void setResourcePersistence(ResourcePersistence resourcePersistence) {
		this.resourcePersistence = resourcePersistence;
	}

	/**
	 * Gets the user local service.
	 *
	 * @return the user local service
	 */
	public UserLocalService getUserLocalService() {
		return userLocalService;
	}

	/**
	 * Sets the user local service.
	 *
	 * @param userLocalService the user local service
	 */
	public void setUserLocalService(UserLocalService userLocalService) {
		this.userLocalService = userLocalService;
	}

	/**
	 * Gets the user remote service.
	 *
	 * @return the user remote service
	 */
	public UserService getUserService() {
		return userService;
	}

	/**
	 * Sets the user remote service.
	 *
	 * @param userService the user remote service
	 */
	public void setUserService(UserService userService) {
		this.userService = userService;
	}

	/**
	 * Gets the user persistence.
	 *
	 * @return the user persistence
	 */
	public UserPersistence getUserPersistence() {
		return userPersistence;
	}

	/**
	 * Sets the user persistence.
	 *
	 * @param userPersistence the user persistence
	 */
	public void setUserPersistence(UserPersistence userPersistence) {
		this.userPersistence = userPersistence;
	}

	/**
	 * Performs an SQL query.
	 *
	 * @param sql the sql query to perform
	 */
	protected void runSQL(String sql) throws SystemException {
		try {
			DataSource dataSource = calEventInvitationPersistence.getDataSource();

			SqlUpdate sqlUpdate = SqlUpdateFactoryUtil.getSqlUpdate(dataSource,
					sql, new int[0]);

			sqlUpdate.update();
		}
		catch (Exception e) {
			throw new SystemException(e);
		}
	}

	@BeanReference(type = CalEventInvitationLocalService.class)
	protected CalEventInvitationLocalService calEventInvitationLocalService;
	@BeanReference(type = CalEventInvitationService.class)
	protected CalEventInvitationService calEventInvitationService;
	@BeanReference(type = CalEventInvitationPersistence.class)
	protected CalEventInvitationPersistence calEventInvitationPersistence;
	@BeanReference(type = CounterLocalService.class)
	protected CounterLocalService counterLocalService;
	@BeanReference(type = ResourceLocalService.class)
	protected ResourceLocalService resourceLocalService;
	@BeanReference(type = ResourceService.class)
	protected ResourceService resourceService;
	@BeanReference(type = ResourcePersistence.class)
	protected ResourcePersistence resourcePersistence;
	@BeanReference(type = UserLocalService.class)
	protected UserLocalService userLocalService;
	@BeanReference(type = UserService.class)
	protected UserService userService;
	@BeanReference(type = UserPersistence.class)
	protected UserPersistence userPersistence;
}