/**
 * Copyright (c) 2000-2010 Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package nl.jteam.demo.service.impl;

import com.liferay.counter.service.CounterLocalServiceUtil;
import com.liferay.portal.kernel.exception.SystemException;
import nl.jteam.demo.NoSuchCalEventInvitationException;
import nl.jteam.demo.model.CalEventInvitation;
import nl.jteam.demo.service.CalEventInvitationLocalServiceUtil;
import nl.jteam.demo.service.base.CalEventInvitationLocalServiceBaseImpl;
import nl.jteam.demo.service.persistence.CalEventInvitationUtil;

/**
 * The implementation of the cal event invitation local service.
 *
 * <p>
 * All custom service methods should be put in this class. Whenever methods are added, rerun ServiceBuilder to copy their definitions into the {@link nl.jteam.demo.service.CalEventInvitationLocalService} interface.
 * </p>
 *
 * <p>
 * Never reference this interface directly. Always use {@link nl.jteam.demo.service.CalEventInvitationLocalServiceUtil} to access the cal event invitation local service.
 * </p>
 *
 * <p>
 * This is a local service. Methods of this service will not have security checks based on the propagated JAAS credentials because this service can only be accessed from within the same VM.
 * </p>
 *
 * @author Brian Wing Shun Chan
 * @see nl.jteam.demo.service.base.CalEventInvitationLocalServiceBaseImpl
 * @see nl.jteam.demo.service.CalEventInvitationLocalServiceUtil
 */
public class CalEventInvitationLocalServiceImpl
	extends CalEventInvitationLocalServiceBaseImpl {

    public CalEventInvitation createCalEventInvitation() throws SystemException {
        long invitationId = CounterLocalServiceUtil.increment(CalEventInvitation.class.getName());
        CalEventInvitation invitation = CalEventInvitationLocalServiceUtil.createCalEventInvitation(invitationId);
        return CalEventInvitationLocalServiceUtil.addCalEventInvitation(invitation);
    }

    public CalEventInvitation fetchByCalEventCopyId(long calEventCopyId) throws SystemException, NoSuchCalEventInvitationException {
        return CalEventInvitationUtil.fetchByCalEventCopyId(calEventCopyId);
    }

}