/**
 * Copyright (c) 2000-2010 Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package nl.jteam.demo.service.persistence;

import com.liferay.portal.NoSuchModelException;
import com.liferay.portal.kernel.annotation.BeanReference;
import com.liferay.portal.kernel.cache.CacheRegistryUtil;
import com.liferay.portal.kernel.dao.orm.EntityCacheUtil;
import com.liferay.portal.kernel.dao.orm.FinderCacheUtil;
import com.liferay.portal.kernel.dao.orm.FinderPath;
import com.liferay.portal.kernel.dao.orm.Query;
import com.liferay.portal.kernel.dao.orm.QueryPos;
import com.liferay.portal.kernel.dao.orm.QueryUtil;
import com.liferay.portal.kernel.dao.orm.Session;
import com.liferay.portal.kernel.exception.SystemException;
import com.liferay.portal.kernel.log.Log;
import com.liferay.portal.kernel.log.LogFactoryUtil;
import com.liferay.portal.kernel.util.GetterUtil;
import com.liferay.portal.kernel.util.InstanceFactory;
import com.liferay.portal.kernel.util.OrderByComparator;
import com.liferay.portal.kernel.util.StringBundler;
import com.liferay.portal.kernel.util.StringPool;
import com.liferay.portal.kernel.util.StringUtil;
import com.liferay.portal.model.ModelListener;
import com.liferay.portal.service.persistence.BatchSessionUtil;
import com.liferay.portal.service.persistence.ResourcePersistence;
import com.liferay.portal.service.persistence.UserPersistence;
import com.liferay.portal.service.persistence.impl.BasePersistenceImpl;

import nl.jteam.demo.NoSuchCalEventInvitationException;
import nl.jteam.demo.model.CalEventInvitation;
import nl.jteam.demo.model.impl.CalEventInvitationImpl;
import nl.jteam.demo.model.impl.CalEventInvitationModelImpl;

import java.io.Serializable;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

/**
 * The persistence implementation for the cal event invitation service.
 *
 * <p>
 * Never modify or reference this class directly. Always use {@link CalEventInvitationUtil} to access the cal event invitation persistence. Modify <code>service.xml</code> and rerun ServiceBuilder to regenerate this class.
 * </p>
 *
 * <p>
 * Caching information and settings can be found in <code>portal.properties</code>
 * </p>
 *
 * @author Brian Wing Shun Chan
 * @see CalEventInvitationPersistence
 * @see CalEventInvitationUtil
 * @generated
 */
public class CalEventInvitationPersistenceImpl extends BasePersistenceImpl<CalEventInvitation>
	implements CalEventInvitationPersistence {
	public static final String FINDER_CLASS_NAME_ENTITY = CalEventInvitationImpl.class.getName();
	public static final String FINDER_CLASS_NAME_LIST = FINDER_CLASS_NAME_ENTITY +
		".List";
	public static final FinderPath FINDER_PATH_FETCH_BY_CALEVENTCOPYID = new FinderPath(CalEventInvitationModelImpl.ENTITY_CACHE_ENABLED,
			CalEventInvitationModelImpl.FINDER_CACHE_ENABLED,
			FINDER_CLASS_NAME_ENTITY, "fetchByCalEventCopyId",
			new String[] { Long.class.getName() });
	public static final FinderPath FINDER_PATH_COUNT_BY_CALEVENTCOPYID = new FinderPath(CalEventInvitationModelImpl.ENTITY_CACHE_ENABLED,
			CalEventInvitationModelImpl.FINDER_CACHE_ENABLED,
			FINDER_CLASS_NAME_LIST, "countByCalEventCopyId",
			new String[] { Long.class.getName() });
	public static final FinderPath FINDER_PATH_FIND_ALL = new FinderPath(CalEventInvitationModelImpl.ENTITY_CACHE_ENABLED,
			CalEventInvitationModelImpl.FINDER_CACHE_ENABLED,
			FINDER_CLASS_NAME_LIST, "findAll", new String[0]);
	public static final FinderPath FINDER_PATH_COUNT_ALL = new FinderPath(CalEventInvitationModelImpl.ENTITY_CACHE_ENABLED,
			CalEventInvitationModelImpl.FINDER_CACHE_ENABLED,
			FINDER_CLASS_NAME_LIST, "countAll", new String[0]);

	/**
	 * Caches the cal event invitation in the entity cache if it is enabled.
	 *
	 * @param calEventInvitation the cal event invitation to cache
	 */
	public void cacheResult(CalEventInvitation calEventInvitation) {
		EntityCacheUtil.putResult(CalEventInvitationModelImpl.ENTITY_CACHE_ENABLED,
			CalEventInvitationImpl.class, calEventInvitation.getPrimaryKey(),
			calEventInvitation);

		FinderCacheUtil.putResult(FINDER_PATH_FETCH_BY_CALEVENTCOPYID,
			new Object[] { new Long(calEventInvitation.getCalEventCopyId()) },
			calEventInvitation);
	}

	/**
	 * Caches the cal event invitations in the entity cache if it is enabled.
	 *
	 * @param calEventInvitations the cal event invitations to cache
	 */
	public void cacheResult(List<CalEventInvitation> calEventInvitations) {
		for (CalEventInvitation calEventInvitation : calEventInvitations) {
			if (EntityCacheUtil.getResult(
						CalEventInvitationModelImpl.ENTITY_CACHE_ENABLED,
						CalEventInvitationImpl.class,
						calEventInvitation.getPrimaryKey(), this) == null) {
				cacheResult(calEventInvitation);
			}
		}
	}

	/**
	 * Clears the cache for all cal event invitations.
	 *
	 * <p>
	 * The {@link com.liferay.portal.kernel.dao.orm.EntityCache} and {@link com.liferay.portal.kernel.dao.orm.FinderCache} are both cleared by this method.
	 * </p>
	 */
	public void clearCache() {
		CacheRegistryUtil.clear(CalEventInvitationImpl.class.getName());
		EntityCacheUtil.clearCache(CalEventInvitationImpl.class.getName());
		FinderCacheUtil.clearCache(FINDER_CLASS_NAME_ENTITY);
		FinderCacheUtil.clearCache(FINDER_CLASS_NAME_LIST);
	}

	/**
	 * Clears the cache for the cal event invitation.
	 *
	 * <p>
	 * The {@link com.liferay.portal.kernel.dao.orm.EntityCache} and {@link com.liferay.portal.kernel.dao.orm.FinderCache} are both cleared by this method.
	 * </p>
	 */
	public void clearCache(CalEventInvitation calEventInvitation) {
		EntityCacheUtil.removeResult(CalEventInvitationModelImpl.ENTITY_CACHE_ENABLED,
			CalEventInvitationImpl.class, calEventInvitation.getPrimaryKey());

		FinderCacheUtil.removeResult(FINDER_PATH_FETCH_BY_CALEVENTCOPYID,
			new Object[] { new Long(calEventInvitation.getCalEventCopyId()) });
	}

	/**
	 * Creates a new cal event invitation with the primary key. Does not add the cal event invitation to the database.
	 *
	 * @param CalEventInvitationId the primary key for the new cal event invitation
	 * @return the new cal event invitation
	 */
	public CalEventInvitation create(long CalEventInvitationId) {
		CalEventInvitation calEventInvitation = new CalEventInvitationImpl();

		calEventInvitation.setNew(true);
		calEventInvitation.setPrimaryKey(CalEventInvitationId);

		return calEventInvitation;
	}

	/**
	 * Removes the cal event invitation with the primary key from the database. Also notifies the appropriate model listeners.
	 *
	 * @param primaryKey the primary key of the cal event invitation to remove
	 * @return the cal event invitation that was removed
	 * @throws com.liferay.portal.NoSuchModelException if a cal event invitation with the primary key could not be found
	 * @throws SystemException if a system exception occurred
	 */
	public CalEventInvitation remove(Serializable primaryKey)
		throws NoSuchModelException, SystemException {
		return remove(((Long)primaryKey).longValue());
	}

	/**
	 * Removes the cal event invitation with the primary key from the database. Also notifies the appropriate model listeners.
	 *
	 * @param CalEventInvitationId the primary key of the cal event invitation to remove
	 * @return the cal event invitation that was removed
	 * @throws nl.jteam.demo.NoSuchCalEventInvitationException if a cal event invitation with the primary key could not be found
	 * @throws SystemException if a system exception occurred
	 */
	public CalEventInvitation remove(long CalEventInvitationId)
		throws NoSuchCalEventInvitationException, SystemException {
		Session session = null;

		try {
			session = openSession();

			CalEventInvitation calEventInvitation = (CalEventInvitation)session.get(CalEventInvitationImpl.class,
					new Long(CalEventInvitationId));

			if (calEventInvitation == null) {
				if (_log.isWarnEnabled()) {
					_log.warn(_NO_SUCH_ENTITY_WITH_PRIMARY_KEY +
						CalEventInvitationId);
				}

				throw new NoSuchCalEventInvitationException(_NO_SUCH_ENTITY_WITH_PRIMARY_KEY +
					CalEventInvitationId);
			}

			return remove(calEventInvitation);
		}
		catch (NoSuchCalEventInvitationException nsee) {
			throw nsee;
		}
		catch (Exception e) {
			throw processException(e);
		}
		finally {
			closeSession(session);
		}
	}

	protected CalEventInvitation removeImpl(
		CalEventInvitation calEventInvitation) throws SystemException {
		calEventInvitation = toUnwrappedModel(calEventInvitation);

		Session session = null;

		try {
			session = openSession();

			if (calEventInvitation.isCachedModel() ||
					BatchSessionUtil.isEnabled()) {
				Object staleObject = session.get(CalEventInvitationImpl.class,
						calEventInvitation.getPrimaryKeyObj());

				if (staleObject != null) {
					session.evict(staleObject);
				}
			}

			session.delete(calEventInvitation);

			session.flush();
		}
		catch (Exception e) {
			throw processException(e);
		}
		finally {
			closeSession(session);
		}

		FinderCacheUtil.clearCache(FINDER_CLASS_NAME_LIST);

		CalEventInvitationModelImpl calEventInvitationModelImpl = (CalEventInvitationModelImpl)calEventInvitation;

		FinderCacheUtil.removeResult(FINDER_PATH_FETCH_BY_CALEVENTCOPYID,
			new Object[] {
				new Long(calEventInvitationModelImpl.getOriginalCalEventCopyId())
			});

		EntityCacheUtil.removeResult(CalEventInvitationModelImpl.ENTITY_CACHE_ENABLED,
			CalEventInvitationImpl.class, calEventInvitation.getPrimaryKey());

		return calEventInvitation;
	}

	public CalEventInvitation updateImpl(
		nl.jteam.demo.model.CalEventInvitation calEventInvitation, boolean merge)
		throws SystemException {
		calEventInvitation = toUnwrappedModel(calEventInvitation);

		boolean isNew = calEventInvitation.isNew();

		CalEventInvitationModelImpl calEventInvitationModelImpl = (CalEventInvitationModelImpl)calEventInvitation;

		Session session = null;

		try {
			session = openSession();

			BatchSessionUtil.update(session, calEventInvitation, merge);

			calEventInvitation.setNew(false);
		}
		catch (Exception e) {
			throw processException(e);
		}
		finally {
			closeSession(session);
		}

		FinderCacheUtil.clearCache(FINDER_CLASS_NAME_LIST);

		EntityCacheUtil.putResult(CalEventInvitationModelImpl.ENTITY_CACHE_ENABLED,
			CalEventInvitationImpl.class, calEventInvitation.getPrimaryKey(),
			calEventInvitation);

		if (!isNew &&
				(calEventInvitation.getCalEventCopyId() != calEventInvitationModelImpl.getOriginalCalEventCopyId())) {
			FinderCacheUtil.removeResult(FINDER_PATH_FETCH_BY_CALEVENTCOPYID,
				new Object[] {
					new Long(calEventInvitationModelImpl.getOriginalCalEventCopyId())
				});
		}

		if (isNew ||
				(calEventInvitation.getCalEventCopyId() != calEventInvitationModelImpl.getOriginalCalEventCopyId())) {
			FinderCacheUtil.putResult(FINDER_PATH_FETCH_BY_CALEVENTCOPYID,
				new Object[] { new Long(calEventInvitation.getCalEventCopyId()) },
				calEventInvitation);
		}

		return calEventInvitation;
	}

	protected CalEventInvitation toUnwrappedModel(
		CalEventInvitation calEventInvitation) {
		if (calEventInvitation instanceof CalEventInvitationImpl) {
			return calEventInvitation;
		}

		CalEventInvitationImpl calEventInvitationImpl = new CalEventInvitationImpl();

		calEventInvitationImpl.setNew(calEventInvitation.isNew());
		calEventInvitationImpl.setPrimaryKey(calEventInvitation.getPrimaryKey());

		calEventInvitationImpl.setCalEventInvitationId(calEventInvitation.getCalEventInvitationId());
		calEventInvitationImpl.setGroupId(calEventInvitation.getGroupId());
		calEventInvitationImpl.setCalEventCopyId(calEventInvitation.getCalEventCopyId());

		return calEventInvitationImpl;
	}

	/**
	 * Finds the cal event invitation with the primary key or throws a {@link com.liferay.portal.NoSuchModelException} if it could not be found.
	 *
	 * @param primaryKey the primary key of the cal event invitation to find
	 * @return the cal event invitation
	 * @throws com.liferay.portal.NoSuchModelException if a cal event invitation with the primary key could not be found
	 * @throws SystemException if a system exception occurred
	 */
	public CalEventInvitation findByPrimaryKey(Serializable primaryKey)
		throws NoSuchModelException, SystemException {
		return findByPrimaryKey(((Long)primaryKey).longValue());
	}

	/**
	 * Finds the cal event invitation with the primary key or throws a {@link nl.jteam.demo.NoSuchCalEventInvitationException} if it could not be found.
	 *
	 * @param CalEventInvitationId the primary key of the cal event invitation to find
	 * @return the cal event invitation
	 * @throws nl.jteam.demo.NoSuchCalEventInvitationException if a cal event invitation with the primary key could not be found
	 * @throws SystemException if a system exception occurred
	 */
	public CalEventInvitation findByPrimaryKey(long CalEventInvitationId)
		throws NoSuchCalEventInvitationException, SystemException {
		CalEventInvitation calEventInvitation = fetchByPrimaryKey(CalEventInvitationId);

		if (calEventInvitation == null) {
			if (_log.isWarnEnabled()) {
				_log.warn(_NO_SUCH_ENTITY_WITH_PRIMARY_KEY +
					CalEventInvitationId);
			}

			throw new NoSuchCalEventInvitationException(_NO_SUCH_ENTITY_WITH_PRIMARY_KEY +
				CalEventInvitationId);
		}

		return calEventInvitation;
	}

	/**
	 * Finds the cal event invitation with the primary key or returns <code>null</code> if it could not be found.
	 *
	 * @param primaryKey the primary key of the cal event invitation to find
	 * @return the cal event invitation, or <code>null</code> if a cal event invitation with the primary key could not be found
	 * @throws SystemException if a system exception occurred
	 */
	public CalEventInvitation fetchByPrimaryKey(Serializable primaryKey)
		throws SystemException {
		return fetchByPrimaryKey(((Long)primaryKey).longValue());
	}

	/**
	 * Finds the cal event invitation with the primary key or returns <code>null</code> if it could not be found.
	 *
	 * @param CalEventInvitationId the primary key of the cal event invitation to find
	 * @return the cal event invitation, or <code>null</code> if a cal event invitation with the primary key could not be found
	 * @throws SystemException if a system exception occurred
	 */
	public CalEventInvitation fetchByPrimaryKey(long CalEventInvitationId)
		throws SystemException {
		CalEventInvitation calEventInvitation = (CalEventInvitation)EntityCacheUtil.getResult(CalEventInvitationModelImpl.ENTITY_CACHE_ENABLED,
				CalEventInvitationImpl.class, CalEventInvitationId, this);

		if (calEventInvitation == null) {
			Session session = null;

			try {
				session = openSession();

				calEventInvitation = (CalEventInvitation)session.get(CalEventInvitationImpl.class,
						new Long(CalEventInvitationId));
			}
			catch (Exception e) {
				throw processException(e);
			}
			finally {
				if (calEventInvitation != null) {
					cacheResult(calEventInvitation);
				}

				closeSession(session);
			}
		}

		return calEventInvitation;
	}

	/**
	 * Finds the cal event invitation where calEventCopyId = &#63; or throws a {@link nl.jteam.demo.NoSuchCalEventInvitationException} if it could not be found.
	 *
	 * @param calEventCopyId the cal event copy id to search with
	 * @return the matching cal event invitation
	 * @throws nl.jteam.demo.NoSuchCalEventInvitationException if a matching cal event invitation could not be found
	 * @throws SystemException if a system exception occurred
	 */
	public CalEventInvitation findByCalEventCopyId(long calEventCopyId)
		throws NoSuchCalEventInvitationException, SystemException {
		CalEventInvitation calEventInvitation = fetchByCalEventCopyId(calEventCopyId);

		if (calEventInvitation == null) {
			StringBundler msg = new StringBundler(4);

			msg.append(_NO_SUCH_ENTITY_WITH_KEY);

			msg.append("calEventCopyId=");
			msg.append(calEventCopyId);

			msg.append(StringPool.CLOSE_CURLY_BRACE);

			if (_log.isWarnEnabled()) {
				_log.warn(msg.toString());
			}

			throw new NoSuchCalEventInvitationException(msg.toString());
		}

		return calEventInvitation;
	}

	/**
	 * Finds the cal event invitation where calEventCopyId = &#63; or returns <code>null</code> if it could not be found. Uses the finder cache.
	 *
	 * @param calEventCopyId the cal event copy id to search with
	 * @return the matching cal event invitation, or <code>null</code> if a matching cal event invitation could not be found
	 * @throws SystemException if a system exception occurred
	 */
	public CalEventInvitation fetchByCalEventCopyId(long calEventCopyId)
		throws SystemException {
		return fetchByCalEventCopyId(calEventCopyId, true);
	}

	/**
	 * Finds the cal event invitation where calEventCopyId = &#63; or returns <code>null</code> if it could not be found, optionally using the finder cache.
	 *
	 * @param calEventCopyId the cal event copy id to search with
	 * @return the matching cal event invitation, or <code>null</code> if a matching cal event invitation could not be found
	 * @throws SystemException if a system exception occurred
	 */
	public CalEventInvitation fetchByCalEventCopyId(long calEventCopyId,
		boolean retrieveFromCache) throws SystemException {
		Object[] finderArgs = new Object[] { calEventCopyId };

		Object result = null;

		if (retrieveFromCache) {
			result = FinderCacheUtil.getResult(FINDER_PATH_FETCH_BY_CALEVENTCOPYID,
					finderArgs, this);
		}

		if (result == null) {
			Session session = null;

			try {
				session = openSession();

				StringBundler query = new StringBundler(2);

				query.append(_SQL_SELECT_CALEVENTINVITATION_WHERE);

				query.append(_FINDER_COLUMN_CALEVENTCOPYID_CALEVENTCOPYID_2);

				String sql = query.toString();

				Query q = session.createQuery(sql);

				QueryPos qPos = QueryPos.getInstance(q);

				qPos.add(calEventCopyId);

				List<CalEventInvitation> list = q.list();

				result = list;

				CalEventInvitation calEventInvitation = null;

				if (list.isEmpty()) {
					FinderCacheUtil.putResult(FINDER_PATH_FETCH_BY_CALEVENTCOPYID,
						finderArgs, list);
				}
				else {
					calEventInvitation = list.get(0);

					cacheResult(calEventInvitation);

					if ((calEventInvitation.getCalEventCopyId() != calEventCopyId)) {
						FinderCacheUtil.putResult(FINDER_PATH_FETCH_BY_CALEVENTCOPYID,
							finderArgs, calEventInvitation);
					}
				}

				return calEventInvitation;
			}
			catch (Exception e) {
				throw processException(e);
			}
			finally {
				if (result == null) {
					FinderCacheUtil.putResult(FINDER_PATH_FETCH_BY_CALEVENTCOPYID,
						finderArgs, new ArrayList<CalEventInvitation>());
				}

				closeSession(session);
			}
		}
		else {
			if (result instanceof List<?>) {
				return null;
			}
			else {
				return (CalEventInvitation)result;
			}
		}
	}

	/**
	 * Finds all the cal event invitations.
	 *
	 * @return the cal event invitations
	 * @throws SystemException if a system exception occurred
	 */
	public List<CalEventInvitation> findAll() throws SystemException {
		return findAll(QueryUtil.ALL_POS, QueryUtil.ALL_POS, null);
	}

	/**
	 * Finds a range of all the cal event invitations.
	 *
	 * <p>
	 * Useful when paginating results. Returns a maximum of <code>end - start</code> instances. <code>start</code> and <code>end</code> are not primary keys, they are indexes in the result set. Thus, <code>0</code> refers to the first result in the set. Setting both <code>start</code> and <code>end</code> to {@link com.liferay.portal.kernel.dao.orm.QueryUtil#ALL_POS} will return the full result set.
	 * </p>
	 *
	 * @param start the lower bound of the range of cal event invitations to return
	 * @param end the upper bound of the range of cal event invitations to return (not inclusive)
	 * @return the range of cal event invitations
	 * @throws SystemException if a system exception occurred
	 */
	public List<CalEventInvitation> findAll(int start, int end)
		throws SystemException {
		return findAll(start, end, null);
	}

	/**
	 * Finds an ordered range of all the cal event invitations.
	 *
	 * <p>
	 * Useful when paginating results. Returns a maximum of <code>end - start</code> instances. <code>start</code> and <code>end</code> are not primary keys, they are indexes in the result set. Thus, <code>0</code> refers to the first result in the set. Setting both <code>start</code> and <code>end</code> to {@link com.liferay.portal.kernel.dao.orm.QueryUtil#ALL_POS} will return the full result set.
	 * </p>
	 *
	 * @param start the lower bound of the range of cal event invitations to return
	 * @param end the upper bound of the range of cal event invitations to return (not inclusive)
	 * @param orderByComparator the comparator to order the results by
	 * @return the ordered range of cal event invitations
	 * @throws SystemException if a system exception occurred
	 */
	public List<CalEventInvitation> findAll(int start, int end,
		OrderByComparator orderByComparator) throws SystemException {
		Object[] finderArgs = new Object[] {
				String.valueOf(start), String.valueOf(end),
				String.valueOf(orderByComparator)
			};

		List<CalEventInvitation> list = (List<CalEventInvitation>)FinderCacheUtil.getResult(FINDER_PATH_FIND_ALL,
				finderArgs, this);

		if (list == null) {
			Session session = null;

			try {
				session = openSession();

				StringBundler query = null;
				String sql = null;

				if (orderByComparator != null) {
					query = new StringBundler(2 +
							(orderByComparator.getOrderByFields().length * 3));

					query.append(_SQL_SELECT_CALEVENTINVITATION);

					appendOrderByComparator(query, _ORDER_BY_ENTITY_ALIAS,
						orderByComparator);

					sql = query.toString();
				}
				else {
					sql = _SQL_SELECT_CALEVENTINVITATION;
				}

				Query q = session.createQuery(sql);

				if (orderByComparator == null) {
					list = (List<CalEventInvitation>)QueryUtil.list(q,
							getDialect(), start, end, false);

					Collections.sort(list);
				}
				else {
					list = (List<CalEventInvitation>)QueryUtil.list(q,
							getDialect(), start, end);
				}
			}
			catch (Exception e) {
				throw processException(e);
			}
			finally {
				if (list == null) {
					list = new ArrayList<CalEventInvitation>();
				}

				cacheResult(list);

				FinderCacheUtil.putResult(FINDER_PATH_FIND_ALL, finderArgs, list);

				closeSession(session);
			}
		}

		return list;
	}

	/**
	 * Removes the cal event invitation where calEventCopyId = &#63; from the database.
	 *
	 * @param calEventCopyId the cal event copy id to search with
	 * @throws SystemException if a system exception occurred
	 */
	public void removeByCalEventCopyId(long calEventCopyId)
		throws NoSuchCalEventInvitationException, SystemException {
		CalEventInvitation calEventInvitation = findByCalEventCopyId(calEventCopyId);

		remove(calEventInvitation);
	}

	/**
	 * Removes all the cal event invitations from the database.
	 *
	 * @throws SystemException if a system exception occurred
	 */
	public void removeAll() throws SystemException {
		for (CalEventInvitation calEventInvitation : findAll()) {
			remove(calEventInvitation);
		}
	}

	/**
	 * Counts all the cal event invitations where calEventCopyId = &#63;.
	 *
	 * @param calEventCopyId the cal event copy id to search with
	 * @return the number of matching cal event invitations
	 * @throws SystemException if a system exception occurred
	 */
	public int countByCalEventCopyId(long calEventCopyId)
		throws SystemException {
		Object[] finderArgs = new Object[] { calEventCopyId };

		Long count = (Long)FinderCacheUtil.getResult(FINDER_PATH_COUNT_BY_CALEVENTCOPYID,
				finderArgs, this);

		if (count == null) {
			Session session = null;

			try {
				session = openSession();

				StringBundler query = new StringBundler(2);

				query.append(_SQL_COUNT_CALEVENTINVITATION_WHERE);

				query.append(_FINDER_COLUMN_CALEVENTCOPYID_CALEVENTCOPYID_2);

				String sql = query.toString();

				Query q = session.createQuery(sql);

				QueryPos qPos = QueryPos.getInstance(q);

				qPos.add(calEventCopyId);

				count = (Long)q.uniqueResult();
			}
			catch (Exception e) {
				throw processException(e);
			}
			finally {
				if (count == null) {
					count = Long.valueOf(0);
				}

				FinderCacheUtil.putResult(FINDER_PATH_COUNT_BY_CALEVENTCOPYID,
					finderArgs, count);

				closeSession(session);
			}
		}

		return count.intValue();
	}

	/**
	 * Counts all the cal event invitations.
	 *
	 * @return the number of cal event invitations
	 * @throws SystemException if a system exception occurred
	 */
	public int countAll() throws SystemException {
		Object[] finderArgs = new Object[0];

		Long count = (Long)FinderCacheUtil.getResult(FINDER_PATH_COUNT_ALL,
				finderArgs, this);

		if (count == null) {
			Session session = null;

			try {
				session = openSession();

				Query q = session.createQuery(_SQL_COUNT_CALEVENTINVITATION);

				count = (Long)q.uniqueResult();
			}
			catch (Exception e) {
				throw processException(e);
			}
			finally {
				if (count == null) {
					count = Long.valueOf(0);
				}

				FinderCacheUtil.putResult(FINDER_PATH_COUNT_ALL, finderArgs,
					count);

				closeSession(session);
			}
		}

		return count.intValue();
	}

	/**
	 * Initializes the cal event invitation persistence.
	 */
	public void afterPropertiesSet() {
		String[] listenerClassNames = StringUtil.split(GetterUtil.getString(
					com.liferay.util.service.ServiceProps.get(
						"value.object.listener.nl.jteam.demo.model.CalEventInvitation")));

		if (listenerClassNames.length > 0) {
			try {
				List<ModelListener<CalEventInvitation>> listenersList = new ArrayList<ModelListener<CalEventInvitation>>();

				for (String listenerClassName : listenerClassNames) {
					listenersList.add((ModelListener<CalEventInvitation>)InstanceFactory.newInstance(
							listenerClassName));
				}

				listeners = listenersList.toArray(new ModelListener[listenersList.size()]);
			}
			catch (Exception e) {
				_log.error(e);
			}
		}
	}

	@BeanReference(type = CalEventInvitationPersistence.class)
	protected CalEventInvitationPersistence calEventInvitationPersistence;
	@BeanReference(type = ResourcePersistence.class)
	protected ResourcePersistence resourcePersistence;
	@BeanReference(type = UserPersistence.class)
	protected UserPersistence userPersistence;
	private static final String _SQL_SELECT_CALEVENTINVITATION = "SELECT calEventInvitation FROM CalEventInvitation calEventInvitation";
	private static final String _SQL_SELECT_CALEVENTINVITATION_WHERE = "SELECT calEventInvitation FROM CalEventInvitation calEventInvitation WHERE ";
	private static final String _SQL_COUNT_CALEVENTINVITATION = "SELECT COUNT(calEventInvitation) FROM CalEventInvitation calEventInvitation";
	private static final String _SQL_COUNT_CALEVENTINVITATION_WHERE = "SELECT COUNT(calEventInvitation) FROM CalEventInvitation calEventInvitation WHERE ";
	private static final String _FINDER_COLUMN_CALEVENTCOPYID_CALEVENTCOPYID_2 = "calEventInvitation.calEventCopyId = ?";
	private static final String _ORDER_BY_ENTITY_ALIAS = "calEventInvitation.";
	private static final String _NO_SUCH_ENTITY_WITH_PRIMARY_KEY = "No CalEventInvitation exists with the primary key ";
	private static final String _NO_SUCH_ENTITY_WITH_KEY = "No CalEventInvitation exists with the key {";
	private static Log _log = LogFactoryUtil.getLog(CalEventInvitationPersistenceImpl.class);
}